package com.chinaitop.depot.api.controller;

import com.chinaitop.depot.api.constant.Constant;
import com.chinaitop.depot.api.model.ResponseEntity;
import com.chinaitop.depot.api.service.FumigationApiService;
import com.chinaitop.depot.api.service.UpApiService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

@RestController
@RequestMapping(value = "/api")
@Api(value = "ApiController", description = "粮情接受控制类")
@SuppressWarnings("all")
public class ApiController {

    final static Logger logger = LoggerFactory.getLogger(ApiController.class);

    @Resource
    private UpApiService upApiService;

    @Resource
    private FumigationApiService fumigationApiService;


    // 参数例子：   {   "id" : "6b8cefa5a9a748a1abaf62dd3b91fd38",   "orgId" : "164",   "storehouse" : "025",   "house" : "001",   "time" : "20201224080350",   "intemp" : 12.7,   "inh" : 75.1,   "outtemp" : 9.8,   "outh" : 70.5,   "max" : 17.6,   "min" : 8.0,   "avg" : 11.8,   "dataSource" : "0",   "updatetime" : null,   "ilqYq" : "0",   "tPoints" : null,   "layerLists" : [ {     "id" : "206a5630cdaa47c7805ec06535c11e4e",     "orgId" : "164",     "lqId" : "6b8cefa5a9a748a1abaf62dd3b91fd38",     "lhouse" : "025",     "ltime" : "20201224080350",     "layernumber" : 3,     "lz" : "3",     "lmax" : 14.5,     "lmin" : 8.8,     "lavg" : 10.2,     "dataSource" : "0",     "updatetime" : "20201224080508"   }, {     "id" : "55eb894e3c854d9bb9c922dbbf546183",     "orgId" : "164",     "lqId" : "6b8cefa5a9a748a1abaf62dd3b91fd38",     "lhouse" : "025",     "ltime" : "20201224080350",     "layernumber" : 1,     "lz" : "1",     "lmax" : 17.6,     "lmin" : 10.8,     "lavg" : 14.0,     "dataSource" : "0",     "updatetime" : "20201224080508"   }, {     "id" : "69422adbe772448baeecf123b1780fc3",     "orgId" : "164",     "lqId" : "6b8cefa5a9a748a1abaf62dd3b91fd38",     "lhouse" : "025",     "ltime" : "20201224080350",     "layernumber" : 2,     "lz" : "2",     "lmax" : 16.5,     "lmin" : 9.5,     "lavg" : 12.1,     "dataSource" : "0",     "updatetime" : "20201224080508"   }, {     "id" : "cf7998f380f548638397d291c4d7f830",     "orgId" : "164",     "lqId" : "6b8cefa5a9a748a1abaf62dd3b91fd38",     "lhouse" : "025",     "ltime" : "20201224080350",     "layernumber" : 4,     "lz" : "4",     "lmax" : 14.8,     "lmin" : 8.0,     "lavg" : 10.7,     "dataSource" : "0",     "updatetime" : "20201224080508"   } ] }
    /* 测温参数例子：
      {
            "id" : "6b8cefa5a9a748a1abaf62dd3b91fd38",
                "orgId" : "164",
                "storehouse" : "025",
                "house" : "001",
                "time" : "20201224080350",
                "intemp" : 12.7,
                "inh" : 75.1,
                "outtemp" : 9.8,
                "outh" : 70.5,
                "max" : 17.6,
                "min" : 8.0,
                "avg" : 11.8,
                "dataSource" : "0",
                "updatetime" : null,
                "ilqYq" : "0",
                "tPoints" : [{"temp":15.7,"x":"1","y":"1","z":"1"},{"temp":13.7,"x":"2","y":"1","z":"1"},{"temp":12.5,"x":"3","y":"1","z":"1"},{"temp":13.1,"x":"4","y":"1","z":"1"},{"temp":14.0,"x":"5","y":"1","z":"1"},{"temp":15.0,"x":"6","y":"1","z":"1"},{"temp":12.5,"x":"7","y":"1","z":"1"},{"temp":15.5,"x":"8","y":"1","z":"1"},{"temp":14.5,"x":"9","y":"1","z":"1"},{"temp":13.1,"x":"10","y":"1","z":"1"},{"temp":15.1,"x":"11","y":"1","z":"1"},{"temp":15.5,"x":"12","y":"1","z":"1"},{"temp":17.6,"x":"13","y":"1","z":"1"},{"temp":14.5,"x":"1","y":"2","z":"1"},{"temp":16.1,"x":"2","y":"2","z":"1"},{"temp":14.6,"x":"3","y":"2","z":"1"},{"temp":14.7,"x":"4","y":"2","z":"1"},{"temp":14.9,"x":"5","y":"2","z":"1"},{"temp":14.3,"x":"6","y":"2","z":"1"},{"temp":13.6,"x":"7","y":"2","z":"1"},{"temp":14.0,"x":"8","y":"2","z":"1"},{"temp":12.6,"x":"9","y":"2","z":"1"},{"temp":15.5,"x":"10","y":"2","z":"1"},{"temp":13.2,"x":"11","y":"2","z":"1"},{"temp":14.2,"x":"12","y":"2","z":"1"},{"temp":17.2,"x":"13","y":"2","z":"1"},{"temp":15.4,"x":"1","y":"3","z":"1"},{"temp":15.3,"x":"2","y":"3","z":"1"},{"temp":14.2,"x":"3","y":"3","z":"1"},{"temp":14.3,"x":"4","y":"3","z":"1"},{"temp":14.1,"x":"5","y":"3","z":"1"},{"temp":13.2,"x":"6","y":"3","z":"1"},{"temp":12.3,"x":"7","y":"3","z":"1"},{"temp":12.9,"x":"8","y":"3","z":"1"},{"temp":12.0,"x":"9","y":"3","z":"1"},{"temp":13.8,"x":"10","y":"3","z":"1"},{"temp":13.0,"x":"11","y":"3","z":"1"},{"temp":13.6,"x":"12","y":"3","z":"1"},{"temp":17.3,"x":"13","y":"3","z":"1"},{"temp":14.9,"x":"1","y":"4","z":"1"},{"temp":15.3,"x":"2","y":"4","z":"1"},{"temp":14.3,"x":"3","y":"4","z":"1"},{"temp":13.7,"x":"4","y":"4","z":"1"},{"temp":13.6,"x":"5","y":"4","z":"1"},{"temp":13.2,"x":"6","y":"4","z":"1"},{"temp":13.1,"x":"7","y":"4","z":"1"},{"temp":12.5,"x":"8","y":"4","z":"1"},{"temp":12.3,"x":"9","y":"4","z":"1"},{"temp":12.7,"x":"10","y":"4","z":"1"},{"temp":12.4,"x":"11","y":"4","z":"1"},{"temp":13.4,"x":"12","y":"4","z":"1"},{"temp":17.5,"x":"13","y":"4","z":"1"},{"temp":15.2,"x":"1","y":"5","z":"1"},{"temp":14.8,"x":"2","y":"5","z":"1"},{"temp":14.8,"x":"3","y":"5","z":"1"},{"temp":14.0,"x":"4","y":"5","z":"1"},{"temp":13.3,"x":"5","y":"5","z":"1"},{"temp":14.6,"x":"6","y":"5","z":"1"},{"temp":13.3,"x":"7","y":"5","z":"1"},{"temp":13.0,"x":"8","y":"5","z":"1"},{"temp":15.6,"x":"9","y":"5","z":"1"},{"temp":12.7,"x":"10","y":"5","z":"1"},{"temp":12.7,"x":"11","y":"5","z":"1"},{"temp":13.8,"x":"12","y":"5","z":"1"},{"temp":17.0,"x":"13","y":"5","z":"1"},{"temp":14.4,"x":"1","y":"6","z":"1"},{"temp":13.6,"x":"2","y":"6","z":"1"},{"temp":12.0,"x":"3","y":"6","z":"1"},{"temp":12.6,"x":"4","y":"6","z":"1"},{"temp":13.3,"x":"5","y":"6","z":"1"},{"temp":12.7,"x":"6","y":"6","z":"1"},{"temp":12.1,"x":"7","y":"6","z":"1"},{"temp":10.8,"x":"8","y":"6","z":"1"},{"temp":14.4,"x":"9","y":"6","z":"1"},{"temp":13.2,"x":"10","y":"6","z":"1"},{"temp":13.7,"x":"11","y":"6","z":"1"},{"temp":12.9,"x":"12","y":"6","z":"1"},{"temp":14.1,"x":"13","y":"6","z":"1"},{"temp":14.5,"x":"1","y":"1","z":"2"},{"temp":10.4,"x":"2","y":"1","z":"2"},{"temp":9.6,"x":"3","y":"1","z":"2"},{"temp":10.9,"x":"4","y":"1","z":"2"},{"temp":13.4,"x":"5","y":"1","z":"2"},{"temp":14.0,"x":"6","y":"1","z":"2"},{"temp":12.9,"x":"7","y":"1","z":"2"},{"temp":12.7,"x":"8","y":"1","z":"2"},{"temp":13.5,"x":"9","y":"1","z":"2"},{"temp":11.5,"x":"10","y":"1","z":"2"},{"temp":11.0,"x":"11","y":"1","z":"2"},{"temp":11.7,"x":"12","y":"1","z":"2"},{"temp":16.5,"x":"13","y":"1","z":"2"},{"temp":12.3,"x":"1","y":"2","z":"2"},{"temp":14.7,"x":"2","y":"2","z":"2"},{"temp":12.5,"x":"3","y":"2","z":"2"},{"temp":11.3,"x":"4","y":"2","z":"2"},{"temp":14.6,"x":"5","y":"2","z":"2"},{"temp":14.0,"x":"6","y":"2","z":"2"},{"temp":12.9,"x":"7","y":"2","z":"2"},{"temp":13.6,"x":"8","y":"2","z":"2"},{"temp":10.4,"x":"9","y":"2","z":"2"},{"temp":14.0,"x":"10","y":"2","z":"2"},{"temp":9.8,"x":"11","y":"2","z":"2"},{"temp":11.0,"x":"12","y":"2","z":"2"},{"temp":16.1,"x":"13","y":"2","z":"2"},{"temp":12.5,"x":"1","y":"3","z":"2"},{"temp":13.6,"x":"2","y":"3","z":"2"},{"temp":12.4,"x":"3","y":"3","z":"2"},{"temp":11.1,"x":"4","y":"3","z":"2"},{"temp":14.0,"x":"5","y":"3","z":"2"},{"temp":13.7,"x":"6","y":"3","z":"2"},{"temp":11.0,"x":"7","y":"3","z":"2"},{"temp":11.2,"x":"8","y":"3","z":"2"},{"temp":10.8,"x":"9","y":"3","z":"2"},{"temp":13.3,"x":"10","y":"3","z":"2"},{"temp":11.3,"x":"11","y":"3","z":"2"},{"temp":11.0,"x":"12","y":"3","z":"2"},{"temp":15.7,"x":"13","y":"3","z":"2"},{"temp":11.7,"x":"1","y":"4","z":"2"},{"temp":14.3,"x":"2","y":"4","z":"2"},{"temp":12.5,"x":"3","y":"4","z":"2"},{"temp":11.1,"x":"4","y":"4","z":"2"},{"temp":14.4,"x":"5","y":"4","z":"2"},{"temp":12.6,"x":"6","y":"4","z":"2"},{"temp":11.8,"x":"7","y":"4","z":"2"},{"temp":11.0,"x":"8","y":"4","z":"2"},{"temp":10.5,"x":"9","y":"4","z":"2"},{"temp":13.0,"x":"10","y":"4","z":"2"},{"temp":11.2,"x":"11","y":"4","z":"2"},{"temp":11.8,"x":"12","y":"4","z":"2"},{"temp":15.3,"x":"13","y":"4","z":"2"},{"temp":12.7,"x":"1","y":"5","z":"2"},{"temp":13.5,"x":"2","y":"5","z":"2"},{"temp":12.4,"x":"3","y":"5","z":"2"},{"temp":10.5,"x":"4","y":"5","z":"2"},{"temp":13.5,"x":"5","y":"5","z":"2"},{"temp":12.7,"x":"6","y":"5","z":"2"},{"temp":11.9,"x":"7","y":"5","z":"2"},{"temp":9.8,"x":"8","y":"5","z":"2"},{"temp":12.5,"x":"9","y":"5","z":"2"},{"temp":13.3,"x":"10","y":"5","z":"2"},{"temp":10.4,"x":"11","y":"5","z":"2"},{"temp":12.0,"x":"12","y":"5","z":"2"},{"temp":14.6,"x":"13","y":"5","z":"2"},{"temp":10.6,"x":"1","y":"6","z":"2"},{"temp":11.0,"x":"2","y":"6","z":"2"},{"temp":9.9,"x":"3","y":"6","z":"2"},{"temp":9.7,"x":"4","y":"6","z":"2"},{"temp":10.4,"x":"5","y":"6","z":"2"},{"temp":10.7,"x":"6","y":"6","z":"2"},{"temp":10.2,"x":"7","y":"6","z":"2"},{"temp":9.5,"x":"8","y":"6","z":"2"},{"temp":11.0,"x":"9","y":"6","z":"2"},{"temp":10.1,"x":"10","y":"6","z":"2"},{"temp":10.1,"x":"11","y":"6","z":"2"},{"temp":10.0,"x":"12","y":"6","z":"2"},{"temp":11.0,"x":"13","y":"6","z":"2"},{"temp":10.6,"x":"1","y":"1","z":"3"},{"temp":10.3,"x":"2","y":"1","z":"3"},{"temp":10.2,"x":"3","y":"1","z":"3"},{"temp":10.0,"x":"4","y":"1","z":"3"},{"temp":12.0,"x":"5","y":"1","z":"3"},{"temp":9.7,"x":"6","y":"1","z":"3"},{"temp":9.8,"x":"7","y":"1","z":"3"},{"temp":9.2,"x":"8","y":"1","z":"3"},{"temp":9.8,"x":"9","y":"1","z":"3"},{"temp":11.6,"x":"10","y":"1","z":"3"},{"temp":9.8,"x":"11","y":"1","z":"3"},{"temp":9.7,"x":"12","y":"1","z":"3"},{"temp":11.5,"x":"13","y":"1","z":"3"},{"temp":11.1,"x":"1","y":"2","z":"3"},{"temp":10.1,"x":"2","y":"2","z":"3"},{"temp":9.3,"x":"3","y":"2","z":"3"},{"temp":9.8,"x":"4","y":"2","z":"3"},{"temp":10.0,"x":"5","y":"2","z":"3"},{"temp":9.3,"x":"6","y":"2","z":"3"},{"temp":9.3,"x":"7","y":"2","z":"3"},{"temp":11.1,"x":"8","y":"2","z":"3"},{"temp":10.1,"x":"9","y":"2","z":"3"},{"temp":9.3,"x":"10","y":"2","z":"3"},{"temp":10.3,"x":"11","y":"2","z":"3"},{"temp":9.7,"x":"12","y":"2","z":"3"},{"temp":12.3,"x":"13","y":"2","z":"3"},{"temp":10.2,"x":"1","y":"3","z":"3"},{"temp":9.0,"x":"2","y":"3","z":"3"},{"temp":9.9,"x":"3","y":"3","z":"3"},{"temp":10.2,"x":"4","y":"3","z":"3"},{"temp":10.5,"x":"5","y":"3","z":"3"},{"temp":9.3,"x":"6","y":"3","z":"3"},{"temp":10.0,"x":"7","y":"3","z":"3"},{"temp":9.2,"x":"8","y":"3","z":"3"},{"temp":9.7,"x":"9","y":"3","z":"3"},{"temp":9.2,"x":"10","y":"3","z":"3"},{"temp":9.0,"x":"11","y":"3","z":"3"},{"temp":9.2,"x":"12","y":"3","z":"3"},{"temp":12.7,"x":"13","y":"3","z":"3"},{"temp":10.5,"x":"1","y":"4","z":"3"},{"temp":9.7,"x":"2","y":"4","z":"3"},{"temp":9.3,"x":"3","y":"4","z":"3"},{"temp":10.3,"x":"4","y":"4","z":"3"},{"temp":14.4,"x":"5","y":"4","z":"3"},{"temp":9.4,"x":"6","y":"4","z":"3"},{"temp":9.5,"x":"7","y":"4","z":"3"},{"temp":9.1,"x":"8","y":"4","z":"3"},{"temp":9.6,"x":"9","y":"4","z":"3"},{"temp":10.9,"x":"10","y":"4","z":"3"},{"temp":9.2,"x":"11","y":"4","z":"3"},{"temp":9.6,"x":"12","y":"4","z":"3"},{"temp":12.0,"x":"13","y":"4","z":"3"},{"temp":10.2,"x":"1","y":"5","z":"3"},{"temp":9.4,"x":"2","y":"5","z":"3"},{"temp":10.3,"x":"3","y":"5","z":"3"},{"temp":10.3,"x":"4","y":"5","z":"3"},{"temp":14.5,"x":"5","y":"5","z":"3"},{"temp":9.5,"x":"6","y":"5","z":"3"},{"temp":9.9,"x":"7","y":"5","z":"3"},{"temp":9.6,"x":"8","y":"5","z":"3"},{"temp":8.9,"x":"9","y":"5","z":"3"},{"temp":13.8,"x":"10","y":"5","z":"3"},{"temp":10.2,"x":"11","y":"5","z":"3"},{"temp":9.3,"x":"12","y":"5","z":"3"},{"temp":11.8,"x":"13","y":"5","z":"3"},{"temp":10.1,"x":"1","y":"6","z":"3"},{"temp":10.5,"x":"2","y":"6","z":"3"},{"temp":10.5,"x":"3","y":"6","z":"3"},{"temp":10.0,"x":"4","y":"6","z":"3"},{"temp":10.3,"x":"5","y":"6","z":"3"},{"temp":9.9,"x":"6","y":"6","z":"3"},{"temp":9.8,"x":"7","y":"6","z":"3"},{"temp":9.8,"x":"8","y":"6","z":"3"},{"temp":8.8,"x":"9","y":"6","z":"3"},{"temp":9.8,"x":"10","y":"6","z":"3"},{"temp":10.2,"x":"11","y":"6","z":"3"},{"temp":10.5,"x":"12","y":"6","z":"3"},{"temp":10.1,"x":"13","y":"6","z":"3"},{"temp":12.3,"x":"1","y":"1","z":"4"},{"temp":9.8,"x":"2","y":"1","z":"4"},{"temp":8.0,"x":"3","y":"1","z":"4"},{"temp":11.0,"x":"4","y":"1","z":"4"},{"temp":11.8,"x":"5","y":"1","z":"4"},{"temp":11.8,"x":"6","y":"1","z":"4"},{"temp":10.4,"x":"7","y":"1","z":"4"},{"temp":9.1,"x":"8","y":"1","z":"4"},{"temp":11.1,"x":"9","y":"1","z":"4"},{"temp":11.7,"x":"10","y":"1","z":"4"},{"temp":10.7,"x":"11","y":"1","z":"4"},{"temp":10.2,"x":"12","y":"1","z":"4"},{"temp":12.1,"x":"13","y":"1","z":"4"},{"temp":13.2,"x":"1","y":"2","z":"4"},{"temp":12.9,"x":"2","y":"2","z":"4"},{"temp":8.7,"x":"3","y":"2","z":"4"},{"temp":8.3,"x":"4","y":"2","z":"4"},{"temp":13.2,"x":"5","y":"2","z":"4"},{"temp":10.6,"x":"6","y":"2","z":"4"},{"temp":9.9,"x":"7","y":"2","z":"4"},{"temp":10.6,"x":"8","y":"2","z":"4"},{"temp":10.7,"x":"9","y":"2","z":"4"},{"temp":9.3,"x":"10","y":"2","z":"4"},{"temp":8.3,"x":"11","y":"2","z":"4"},{"temp":10.1,"x":"12","y":"2","z":"4"},{"temp":11.8,"x":"13","y":"2","z":"4"},{"temp":12.2,"x":"1","y":"3","z":"4"},{"temp":11.6,"x":"2","y":"3","z":"4"},{"temp":8.5,"x":"3","y":"3","z":"4"},{"temp":9.5,"x":"4","y":"3","z":"4"},{"temp":12.0,"x":"5","y":"3","z":"4"},{"temp":11.3,"x":"6","y":"3","z":"4"},{"temp":9.6,"x":"7","y":"3","z":"4"},{"temp":10.6,"x":"8","y":"3","z":"4"},{"temp":9.4,"x":"9","y":"3","z":"4"},{"temp":10.2,"x":"10","y":"3","z":"4"},{"temp":9.8,"x":"11","y":"3","z":"4"},{"temp":10.4,"x":"12","y":"3","z":"4"},{"temp":12.0,"x":"13","y":"3","z":"4"},{"temp":9.6,"x":"1","y":"4","z":"4"},{"temp":11.5,"x":"2","y":"4","z":"4"},{"temp":9.6,"x":"3","y":"4","z":"4"},{"temp":8.5,"x":"4","y":"4","z":"4"},{"temp":14.8,"x":"5","y":"4","z":"4"},{"temp":11.6,"x":"6","y":"4","z":"4"},{"temp":10.7,"x":"7","y":"4","z":"4"},{"temp":9.5,"x":"8","y":"4","z":"4"},{"temp":9.4,"x":"9","y":"4","z":"4"},{"temp":11.1,"x":"10","y":"4","z":"4"},{"temp":9.3,"x":"11","y":"4","z":"4"},{"temp":10.6,"x":"12","y":"4","z":"4"},{"temp":11.4,"x":"13","y":"4","z":"4"},{"temp":10.5,"x":"1","y":"5","z":"4"},{"temp":12.6,"x":"2","y":"5","z":"4"},{"temp":9.1,"x":"3","y":"5","z":"4"},{"temp":8.8,"x":"4","y":"5","z":"4"},{"temp":12.6,"x":"5","y":"5","z":"4"},{"temp":12.2,"x":"6","y":"5","z":"4"},{"temp":11.3,"x":"7","y":"5","z":"4"},{"temp":11.6,"x":"8","y":"5","z":"4"},{"temp":9.8,"x":"9","y":"5","z":"4"},{"temp":14.3,"x":"10","y":"5","z":"4"},{"temp":9.5,"x":"11","y":"5","z":"4"},{"temp":10.9,"x":"12","y":"5","z":"4"},{"temp":10.7,"x":"13","y":"5","z":"4"},{"temp":10.0,"x":"1","y":"6","z":"4"},{"temp":12.0,"x":"2","y":"6","z":"4"},{"temp":11.6,"x":"3","y":"6","z":"4"},{"temp":10.8,"x":"4","y":"6","z":"4"},{"temp":9.8,"x":"5","y":"6","z":"4"},{"temp":11.7,"x":"6","y":"6","z":"4"},{"temp":11.1,"x":"7","y":"6","z":"4"},{"temp":11.3,"x":"8","y":"6","z":"4"},{"temp":10.3,"x":"9","y":"6","z":"4"},{"temp":9.6,"x":"10","y":"6","z":"4"},{"temp":9.8,"x":"11","y":"6","z":"4"},{"temp":9.8,"x":"12","y":"6","z":"4"},{"temp":10.4,"x":"13","y":"6","z":"4"}],
            "layerLists" : [ {
            "id" : "206a5630cdaa47c7805ec06535c11e4e",
                    "orgId" : "164",
                    "lqId" : "6b8cefa5a9a748a1abaf62dd3b91fd38",
                    "lhouse" : "025",
                    "ltime" : "20201224080350",
                    "layernumber" : 3,
                    "lz" : "3",
                    "lmax" : 14.5,
                    "lmin" : 8.8,
                    "lavg" : 10.2,
                    "dataSource" : "0",
                    "updatetime" : "20201224080508"
        }, {
            "id" : "55eb894e3c854d9bb9c922dbbf546183",
                    "orgId" : "164",
                    "lqId" : "6b8cefa5a9a748a1abaf62dd3b91fd38",
                    "lhouse" : "025",
                    "ltime" : "20201224080350",
                    "layernumber" : 1,
                    "lz" : "1",
                    "lmax" : 17.6,
                    "lmin" : 10.8,
                    "lavg" : 14.0,
                    "dataSource" : "0",
                    "updatetime" : "20201224080508"
        }, {
            "id" : "69422adbe772448baeecf123b1780fc3",
                    "orgId" : "164",
                    "lqId" : "6b8cefa5a9a748a1abaf62dd3b91fd38",
                    "lhouse" : "025",
                    "ltime" : "20201224080350",
                    "layernumber" : 2,
                    "lz" : "2",
                    "lmax" : 16.5,
                    "lmin" : 9.5,
                    "lavg" : 12.1,
                    "dataSource" : "0",
                    "updatetime" : "20201224080508"
        }, {
            "id" : "cf7998f380f548638397d291c4d7f830",
                    "orgId" : "164",
                    "lqId" : "6b8cefa5a9a748a1abaf62dd3b91fd38",
                    "lhouse" : "025",
                    "ltime" : "20201224080350",
                    "layernumber" : 4,
                    "lz" : "4",
                    "lmax" : 14.8,
                    "lmin" : 8.0,
                    "lavg" : 10.7,
                    "dataSource" : "0",
                    "updatetime" : "20201224080508"
        } ]
        }*/
    @RequestMapping(value = "/grain/saveGrain", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "新增测温数据", notes = "新增测温数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "grainJson", value = "表数据json串", paramType = "form")
    })
    public ResponseEntity saveGrain(@RequestBody String grainJson) {
        if (StringUtils.isBlank(grainJson)) {
            logger.error(Constant.JSON_FAILED);
            return ResponseEntity.failed(Constant.JSON_FAILED);
        }
        String save = null;
        try {
            save = upApiService.saveGrain(grainJson);
        } catch (Exception e) {
            logger.error(e.getMessage());
            return ResponseEntity.failed(Constant.FAILED);
        }

        return ResponseEntity.ok(save);
    }


    /* 参数实例：
    [
    {
        "id": "6b8cefa5a9a748a1abaf63dd3b91fd48",
        "orgId": "163",
        "vCcCode": "10001",
        "vCfCode": "001",
        "iTdh": 1,
        "iValue": 0,
        "vUpdateTime": "20210507165020",
        "cImage": null,
        "vRemark": ""
    },
    {
        "id": "6b8cefa5a9a748a1abaf62dd3b91fd38",
        "orgId": "163",
        "vCcCode": "10001",
        "vCfCode": "001",
        "iTdh": 2,
        "iValue": 0,
        "vUpdateTime": "20210507165020",
        "cImage": null,
        "vRemark": ""
    },
    {
        "id": "6b8cefa5a9a748a1abaf65dd3b91fd68",
        "orgId": "163",
        "vCcCode": "10001",
        "vCfCode": "001",
        "iTdh": 3,
        "iValue": 0,
        "vUpdateTime": "20210507165020",
        "cImage": null,
        "vRemark": ""
    }
]
    */
    @RequestMapping(value = "/insect/saveInsect", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "新增虫害数据", notes = "新增虫害数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "insectJson", value = "表数据json串", paramType = "form")
    })
    public ResponseEntity saveInsect(@RequestBody String insectJson) {
        if (StringUtils.isBlank(insectJson)) {
            logger.error(Constant.JSON_FAILED);
            return ResponseEntity.failed(Constant.JSON_FAILED);
        }
        String save = null;
        try {
            save = upApiService.saveInsect(insectJson);
        } catch (Exception e) {
            logger.error(e.getMessage());
            return ResponseEntity.failed(Constant.FAILED);
        }

        return ResponseEntity.ok(save);
    }

   /* 请求实例：
   [
    {
        "id": "6b8cefa5a9a748a1abaf63dd3b91fd48",
        "orgId": "163",
        "vDcsCode": "10001",
        "vCfCode": "001",
        "iTdh": 1,
        "iValue": 16,
        "vDevKindCode": "6979",
        "vUpdateTime": "20210507165020",
        "vRemark": ""
    },
    {
        "id": "6b8cefa5a9a748a1abaf62dd3b91fd38",
        "orgId": "163",
        "vDcsCode": "10001",
        "vCfCode": "001",
        "iTdh": 2,
        "iValue": 13,
        "vDevKindCode": "6979",
        "vUpdateTime": "20210507165020",
        "vRemark": ""
    },
    {
        "id": "6b8cefa5a9a748a1abaf65dd3b91fd68",
        "orgId": "163",
        "vDcsCode": "10001",
        "vCfCode": "001",
        "iTdh": 1,
        "iValue": 21,
        "vDevKindCode": "6980",
        "vUpdateTime": "20210507165020",
        "vRemark": ""
    },
    {
        "id": "6b8cefa5a9a748a1abaf65dd3b91fd77",
        "orgId": "163",
        "vDcsCode": "10001",
        "vCfCode": "001",
        "iTdh": 2,
        "iValue": 25,
        "vDevKindCode": "6980",
        "vUpdateTime": "20210507165020",
        "vRemark": ""
    },
    {
        "id": "6b8cefa5a9a748a1abaf65dd3b91fd98",
        "orgId": "163",
        "vDcsCode": "10001",
        "vCfCode": "001",
        "iTdh": 1,
        "iValue": 33,
        "vDevKindCode": "6981",
        "vUpdateTime": "20210507165020",
        "vRemark": ""
    },
    {
        "id": "6b8cefa5a9a748a1abaf65dd3b91fd99",
        "orgId": "163",
        "vDcsCode": "10001",
        "vCfCode": "001",
        "iTdh": 2,
        "iValue": 23,
        "vDevKindCode": "6981",
        "vUpdateTime": "20210507165020",
        "vRemark": ""
    }
]
   * */
    @RequestMapping(value = "/gas/saveGas", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "新增气体数据", notes = "新增气体数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "gasJson", value = "表数据json串", paramType = "form")
    })
    public ResponseEntity saveGas(@RequestBody String gasJson) {
        if (StringUtils.isBlank(gasJson)) {
            logger.error(Constant.JSON_FAILED);
            return ResponseEntity.failed(Constant.JSON_FAILED);
        }
        String save = null;
        try {
            save = upApiService.saveGas(gasJson);
        } catch (Exception e) {
            logger.error(e.getMessage());
            return ResponseEntity.failed(Constant.FAILED);
        }

        return ResponseEntity.ok(save);
    }



    // 参数例子：   {   "id" : "6b8cefa5a9a748a1abaf62dd3b91fd38",   "orgId" : "164",   "storehouse" : "025",   "house" : "001",   "time" : "20201224080350",   "intemp" : 12.7,   "inh" : 75.1,   "outtemp" : 9.8,   "outh" : 70.5,   "max" : 17.6,   "min" : 8.0,   "avg" : 11.8,   "dataSource" : "0",   "updatetime" : null,   "ilqYq" : "0",   "tPoints" : null,   "layerLists" : [ {     "id" : "206a5630cdaa47c7805ec06535c11e4e",     "orgId" : "164",     "lqId" : "6b8cefa5a9a748a1abaf62dd3b91fd38",     "lhouse" : "025",     "ltime" : "20201224080350",     "layernumber" : 3,     "lz" : "3",     "lmax" : 14.5,     "lmin" : 8.8,     "lavg" : 10.2,     "dataSource" : "0",     "updatetime" : "20201224080508"   }, {     "id" : "55eb894e3c854d9bb9c922dbbf546183",     "orgId" : "164",     "lqId" : "6b8cefa5a9a748a1abaf62dd3b91fd38",     "lhouse" : "025",     "ltime" : "20201224080350",     "layernumber" : 1,     "lz" : "1",     "lmax" : 17.6,     "lmin" : 10.8,     "lavg" : 14.0,     "dataSource" : "0",     "updatetime" : "20201224080508"   }, {     "id" : "69422adbe772448baeecf123b1780fc3",     "orgId" : "164",     "lqId" : "6b8cefa5a9a748a1abaf62dd3b91fd38",     "lhouse" : "025",     "ltime" : "20201224080350",     "layernumber" : 2,     "lz" : "2",     "lmax" : 16.5,     "lmin" : 9.5,     "lavg" : 12.1,     "dataSource" : "0",     "updatetime" : "20201224080508"   }, {     "id" : "cf7998f380f548638397d291c4d7f830",     "orgId" : "164",     "lqId" : "6b8cefa5a9a748a1abaf62dd3b91fd38",     "lhouse" : "025",     "ltime" : "20201224080350",     "layernumber" : 4,     "lz" : "4",     "lmax" : 14.8,     "lmin" : 8.0,     "lavg" : 10.7,     "dataSource" : "0",     "updatetime" : "20201224080508"   } ] }
    @RequestMapping(value = "/grain/saveFumigation", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "新增熏蒸数据", notes = "新增熏蒸数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "dumigationJson", value = "熏蒸表数据json串", paramType = "form")
    })
    public ResponseEntity saveFumigation(@RequestBody String dumigationJson) {
        if (StringUtils.isBlank(dumigationJson)) {
            logger.error(Constant.JSON_FAILED);
            return ResponseEntity.failed(Constant.JSON_FAILED);
        }
        String save = null;
        try {
            save = fumigationApiService.saveFumigation(dumigationJson);
        } catch (Exception e) {
            logger.error(e.getMessage());
            return ResponseEntity.failed(Constant.FAILED);
        }

        return ResponseEntity.ok(save);
    }
}
