package com.chinaitop.depot.api.controller;

import com.chinaitop.depot.api.constant.Constant;
import com.chinaitop.depot.api.model.ResponseEntity;
import com.chinaitop.depot.api.service.BusinessService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

@RestController
@RequestMapping(value = "/api/business")
@Api(value = "BusinessController", description = "综合业务控制类")
@SuppressWarnings("all")
public class BusinessController {

    final static Logger logger = LoggerFactory.getLogger(BusinessController.class);

    @Resource
    private BusinessService businessService;


    //参数例子
    /**
     * 
     * {
    
    "orgId":"164",
    "detailLists":[
        {
            "id":"206a5630cdaa47c7805ec06535c11e4e",
            "orgId":"164"
        },
        {
            "id":"206a5630cdaa47c7805ec06535c11e4e",
            "orgId":"164"
        }
    ]
}
     */
    @RequestMapping(value = "/plan/save", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "新增计划数据", notes = "新增计划数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planJson", value = "表数据json串", paramType = "form")
    })
    public ResponseEntity planSave(@RequestBody String planJson) {
        if (StringUtils.isBlank(planJson)) {
            logger.error(Constant.JSON_FAILED);
            return ResponseEntity.failed(Constant.JSON_FAILED);
        }
        String save = null;
        try {
            save = businessService.planSave(planJson);
        } catch (Exception e) {
            logger.error(e.getMessage());
            return ResponseEntity.failed(Constant.FAILED);
        }

        return ResponseEntity.ok(save);
    }
    
    
    
    @RequestMapping(value = "/contract/save", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "新增合同数据", notes = "新增合同数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "contractJson", value = "表数据json串", paramType = "form")
    })
    public ResponseEntity contractSave(@RequestBody String contractJson) {
        if (StringUtils.isBlank(contractJson)) {
            logger.error(Constant.JSON_FAILED);
            return ResponseEntity.failed(Constant.JSON_FAILED);
        }
        String save = null;
        try {
            save = businessService.contractSave(contractJson);
        } catch (Exception e) {
            logger.error(e.getMessage());
            return ResponseEntity.failed(Constant.FAILED);
        }

        return ResponseEntity.ok(save);
    }
    
    
    @RequestMapping(value = "/notice/save", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "新增通知单数据", notes = "新增通知单数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "noticeJson", value = "表数据json串", paramType = "form")
    })
    public ResponseEntity noticeSave(@RequestBody String noticeJson) {
        if (StringUtils.isBlank(noticeJson)) {
            logger.error(Constant.JSON_FAILED);
            return ResponseEntity.failed(Constant.JSON_FAILED);
        }
        String save = null;
        try {
            save = businessService.noticeSave(noticeJson);
        } catch (Exception e) {
            logger.error(e.getMessage());
            return ResponseEntity.failed(Constant.FAILED);
        }

        return ResponseEntity.ok(save);
    }


}
