package com.chinaitop.depot.api.service.impl;

import com.chinaitop.depot.api.constant.Constant;
import com.chinaitop.depot.api.mapper.BusinessContractMapper;
import com.chinaitop.depot.api.mapper.BusinessDeliveryStorageNoticeMapper;
import com.chinaitop.depot.api.mapper.BusinessPlanMapper;
import com.chinaitop.depot.api.mapper.BusinessStoreWareDetailMapper;
import com.chinaitop.depot.api.model.BusinessContract;
import com.chinaitop.depot.api.model.BusinessDeliveryStorageNotice;
import com.chinaitop.depot.api.model.BusinessPlan;
import com.chinaitop.depot.api.model.BusinessStoreWareDetail;
import com.chinaitop.depot.api.model.StoreWareType;
import com.chinaitop.depot.api.service.BusinessService;
import com.fasterxml.jackson.databind.ObjectMapper;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

@Service
public class BusinessServiceImpl implements BusinessService {

	public static ObjectMapper mapper = new ObjectMapper();
	
    @Autowired
    private BusinessPlanMapper businessPlanMapper;
    
    @Autowired
    private BusinessContractMapper businessContractMapper;
    
    @Autowired
    private BusinessDeliveryStorageNoticeMapper businessDeliveryStorageNoticeMapper;

    @Autowired
    private BusinessStoreWareDetailMapper businessStoreWareDetailMapper;


    
    @Transactional
    @Override
    public String planSave(String planJson) throws Exception {
    	//BusinessPlan businessPlan = JsonToObjectUtils.jsonToTestdataDO(planJson);
    	BusinessPlan businessPlan = mapper.readValue(planJson, BusinessPlan.class);
    	List<BusinessStoreWareDetail>  detailList = businessPlan.getDetailLists();
    	//主表插入数据
    	businessPlanMapper.insert(businessPlan);
    	//子表数据
    	if(detailList.size()>0){
    		for (BusinessStoreWareDetail businessStoreWareDetail : detailList) {
    			businessStoreWareDetail.setZid(businessPlan.getId());
    			businessStoreWareDetail.setType(StoreWareType.plan.getValue());
    			businessStoreWareDetailMapper.insert(businessStoreWareDetail);
			}
    	}
        return Constant.SUCCESS;
    }



    @Transactional
	@Override
	public String contractSave(String contractJson) throws Exception {
		// TODO Auto-generated method stub
    	BusinessContract businessContract = mapper.readValue(contractJson, BusinessContract.class);
    	List<BusinessStoreWareDetail>  detailList = businessContract.getDetailLists();
    	//主表插入数据
    	businessContractMapper.insert(businessContract);
    	//子表数据
    	if(detailList.size()>0){
    		for (BusinessStoreWareDetail businessStoreWareDetail : detailList) {
    			businessStoreWareDetail.setZid(businessContract.getId());
    			businessStoreWareDetail.setType(StoreWareType.contract.getValue());
    			businessStoreWareDetailMapper.insert(businessStoreWareDetail);
			}
    	}
        return Constant.SUCCESS;
	}
    
    
    @Transactional
    @Override
    public String noticeSave(String noticeJson) throws Exception {
    	//BusinessPlan businessPlan = JsonToObjectUtils.jsonToTestdataDO(planJson);
    	BusinessDeliveryStorageNotice notice = mapper.readValue(noticeJson, BusinessDeliveryStorageNotice.class);
    	List<BusinessStoreWareDetail>  detailList = notice.getDetailLists();
    	//主表插入数据
    	businessDeliveryStorageNoticeMapper.insert(notice);
    	//子表数据
    	if(detailList.size()>0){
    		for (BusinessStoreWareDetail businessStoreWareDetail : detailList) {
    			businessStoreWareDetail.setZid(notice.getId());
    			businessStoreWareDetail.setType(StoreWareType.notice.getValue());
    			businessStoreWareDetailMapper.insert(businessStoreWareDetail);
			}
    	}
        return Constant.SUCCESS;
    }
}
