package com.chinaitop.depot.api.service.impl;

import com.chinaitop.depot.api.constant.Constant;
import com.chinaitop.depot.api.mapper.TTestdataLayerMapper;
import com.chinaitop.depot.api.mapper.TTestdataMapper;
import com.chinaitop.depot.api.model.*;
import com.chinaitop.depot.api.service.GasDetectionService;
import com.chinaitop.depot.api.service.InsectPestDetectionService;
import com.chinaitop.depot.api.service.UpApiService;
import com.chinaitop.depot.api.utils.JsonToObjectUtils;
import com.chinaitop.depot.api.utils.Uuid;
import com.google.common.collect.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Service
public class UpApiServiceImpl implements UpApiService {

    @Autowired
    private TTestdataMapper testdataMapper;

    @Autowired
    private TTestdataLayerMapper testdataLayerMapper;

    @Autowired
    private InsectPestDetectionService insectPestDetectionService;

    @Autowired
    private GasDetectionService gasDetectionService;


    /*  TTestdataLayerExample example = new TTestdataLayerExample();
        TTestdataLayerExample.Criteria criteria = example.createCriteria();
        criteria.andLqIdEqualTo("6b8cefa5a9a748a1abaf62dd3b91fd38");
        List<TTestdataLayer> tTestdataLayers = testdataLayerMapper.selectByExample(example);

        TestdataDO doa = new TestdataDO();
        doa.setId(tTestdata2.getId());
        doa.setOrgId(tTestdata2.getOrgId());
        doa.setStorehouse(tTestdata2.getStorehouse());
        doa.setHouse(tTestdata2.getHouse());
        doa.setTime(tTestdata2.getTime());
        doa.setIntemp(tTestdata2.getIntemp());
        doa.setInh(tTestdata2.getInh());
        doa.setOuttemp(tTestdata2.getOuttemp());
        doa.setOuth(tTestdata2.getOuth());
        doa.setMax(tTestdata2.getMax());
        doa.setMin(tTestdata2.getMin());
        doa.setAvg(tTestdata2.getAvg());
        doa.setDataSource(tTestdata2.getDataSource());
        doa.setIlqYq(tTestdata2.getIlqYq());
        doa.settPoints(tTestdata2.gettPoints());
        doa.setLayerLists(tTestdataLayers);

        String s = JsonToObjectUtils.testdataDOToJson(doa);
        System.out.println(s);*/
    @Transactional
    @Override
    public String saveGrain(String grainJson) throws Exception {
        TestdataDO testdataDO = JsonToObjectUtils.jsonToTestdataDO(grainJson);
        List<TPoints> tPoints = testdataDO.gettPoints();
        String s = JsonToObjectUtils.listToString(tPoints);
        testdataDO.setPoints(s);
        TTestdata tTestdata = testdataMapper.selectByPrimaryKey(testdataDO.getId());
        if (tTestdata != null) {
            return Constant.REPEAT_UPLOAD;
        }
        //主表插入数据
        testdataMapper.insertSelectiveDO(testdataDO);
        //获取字表数据
        List<TTestdataLayer> layerLists = testdataDO.getLayerLists();
        if (layerLists.size() > Constant.ZERO) {
            //字表插入数据
            testdataLayerMapper.insertBatch(layerLists);
        }
        return Constant.SUCCESS;
    }

    @Transactional
    @Override
    public String saveInsect(String insectJson) throws Exception {
        ArrayList<TCcdata> tCcdatas = JsonToObjectUtils.jsonToTCcdata(insectJson, TCcdata.class);
        List<String> cDcsId = tCcdatas.stream().map(TCcdata::getId).collect(Collectors.toList());
        //校验重复数据
        for (String id : cDcsId) {
            TCcdata byId = insectPestDetectionService.getById(id);
            if (byId != null) {
                return Constant.REPEAT;
            }
        }
        //获取测虫
        if (tCcdatas.size() > Constant.ZERO) {
            ArrayList<TCcvalue> tCcvalues = Lists.newArrayList();

            Map<String, List<TCcdata>> codeTCcdates = tCcdatas.stream().collect(Collectors.groupingBy(tCcdata -> tCcdata.getvCcCode()));
            for (Map.Entry<String, List<TCcdata>> entry : codeTCcdates.entrySet()) {
                String key = entry.getKey();
                List<TCcdata> values = entry.getValue();
                TCcdata ccdata = values.get(Constant.ZERO);
                int asIntMax = values.stream().mapToInt(TCcdata::getiValue).max().getAsInt();
                int asIntMin = values.stream().mapToInt(TCcdata::getiValue).min().getAsInt();
                BigDecimal avg = new BigDecimal(values.stream().mapToInt(TCcdata::getiValue).average().getAsDouble());
                TCcvalue cv = new TCcvalue(Uuid.getUUID(), ccdata.getOrgId(), key, null, ccdata.getvCfCode(), asIntMax, asIntMin, avg, ccdata.getvUpdateTime(), null);
                tCcvalues.add(cv);
            }
            if (tCcdatas.size() > Constant.ZERO) {
                insectPestDetectionService.insertBatch(tCcdatas);
            }
            if (tCcvalues.size() > Constant.ZERO) {
                insectPestDetectionService.insertValueBatch(tCcvalues);
            }
        }
        return Constant.SUCCESS;
    }

    @Transactional
    @Override
    public String saveGas(String gasJson) throws Exception {
        ArrayList<TDcsdata> tDcsdatas = JsonToObjectUtils.jsonToTDcsdata(gasJson, TDcsdata.class);
        List<String> ids = tDcsdatas.stream().map(TDcsdata::getId).collect(Collectors.toList());
        for (String id : ids) {
            TDcsdata byId = gasDetectionService.getById(id);
            if (byId != null) {
                return Constant.REPEAT;
            }
        }
        //测气数据处理
        if (tDcsdatas.size() > Constant.ZERO) {
            ArrayList<TQtdevinfoValue> tQtdevinfoValues = Lists.newArrayList();
            Map<String, Map<String, List<TDcsdata>>> codeTDcsdatas = tDcsdatas.stream().collect(Collectors.groupingBy(tDcsdata -> tDcsdata.getvDcsCode(), Collectors.groupingBy(tDcsdata -> tDcsdata.getvDevKindCode())));
            for (Map.Entry<String, Map<String, List<TDcsdata>>> entry : codeTDcsdatas.entrySet()) {
                Map<String, List<TDcsdata>> value = entry.getValue();
                //获取报警阈值信息 6971测气 6979二氧化碳 6980氧气 6981磷化氢
                for (Map.Entry<String, List<TDcsdata>> en : value.entrySet()) {
                    List<TDcsdata> value1 = en.getValue();
                    TDcsdata dcsdata = value1.get(Constant.ZERO);
                    BigDecimal avg = null;
                    if (value1.size() > Constant.ZERO) {
                        BigDecimal reduce = value1.stream().map(TDcsdata::getiValue).reduce(BigDecimal.ZERO, BigDecimal::add);
                        double rSum = reduce.doubleValue();
                        double avg_ = rSum / value1.size();
                        avg = new BigDecimal(avg_).setScale(Constant.TWO, BigDecimal.ROUND_DOWN);
                    }
                    TQtdevinfoValue tQtdevinfoValue = new TQtdevinfoValue(Uuid.getUUID(), dcsdata.getOrgId(), dcsdata.getvCfCode(), dcsdata.getvDcsCode(), dcsdata.getvUpdateTime(), avg, dcsdata.getvDevKindCode(), null, null);
                    tQtdevinfoValues.add(tQtdevinfoValue);
                }
            }
            if (tDcsdatas.size() > Constant.ZERO) {
                gasDetectionService.insertBatch(tDcsdatas);
            }
            if (tQtdevinfoValues.size() > Constant.ZERO) {
                gasDetectionService.insertValueBatch(tQtdevinfoValues);
            }
        }
        return Constant.SUCCESS;
    }
}
