package com.chinaitop.depot.api.utils;

import com.chinaitop.depot.api.model.TCcdata;
import com.chinaitop.depot.api.model.TDcsdata;
import com.chinaitop.depot.api.model.TPoints;
import com.chinaitop.depot.api.model.TestdataDO;
import com.chinaitop.depot.api.model.fumigation.TFumigationPlan;
import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.JavaType;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.List;

public class JsonToObjectUtils {

    public static ObjectMapper mapper = new ObjectMapper();

    static {
        // 转换为格式化的json
        mapper.enable(SerializationFeature.INDENT_OUTPUT);
        // 如果json中有新增的字段并且是实体类类中不存在的，不报错
        mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
        mapper.setDateFormat(new SimpleDateFormat("yyyyMMddHHmmss"));
    }

    /**
     * 将字符串转换成list
     *
     * @param str 要转换的字符json串
     * @return list对象
     */
    public static TestdataDO jsonToTestdataDO(String str) throws Exception {
        TestdataDO testdataDO = mapper.readValue(str, TestdataDO.class);
        return testdataDO;
    }

    /**
     * 将对象转换成字符串
     */
    public static String testdataDOToJson(TestdataDO testdataDO) throws Exception {
        String jsonStr = mapper.writeValueAsString(testdataDO);
        return jsonStr;
    }

    /**
     * list转换字符串
     *
     * @param points list参数
     * @return
     */
    public static String listToString(List<TPoints> points) throws Exception {
        return mapper.writeValueAsString(points);
    }

    /**
     * 将字符串转换成list 气体
     *
     * @param str    要转换的字符json串
     * @param classs 实体
     * @return list对象
     */
    public static ArrayList<TDcsdata> jsonToTDcsdata(String str, Class<?> classs) throws Exception {
        JavaType javaType = mapper.getTypeFactory().constructParametricType(ArrayList.class, classs);
        ArrayList<TDcsdata> object = mapper.readValue(str, javaType);
        return object;
    }
    /**
     * 将字符串转换成list 虫害
     *
     * @param str    要转换的字符json串
     * @param classs 实体
     * @return list对象
     */
    public static ArrayList<TCcdata> jsonToTCcdata(String str, Class<?> classs) throws Exception {
        JavaType javaType = mapper.getTypeFactory().constructParametricType(ArrayList.class, classs);
        ArrayList<TCcdata> object = mapper.readValue(str, javaType);
        return object;
    }

    /**
     * 将字符串转换成list
     *
     * @param str 要转换的字符json串
     * @return list对象
     */
    public static TFumigationPlan jsonTFumigationPlan(String str) throws Exception {
        TFumigationPlan tFumigationPlan = mapper.readValue(str, TFumigationPlan.class);
        return tFumigationPlan;
    }
}
